local mod = ...

--[[

    Changes various balancing factors

    General principles
    - Gold maintenance represents the wage paid to workers, plus maintenance if the building is complex. 
        1 gold is a low-skill worker wage per worker
        4 gold is paid to a semi-skilled manual worker (carpenter, etc)
        8 gold is paid to a skilled or professional worker (weaver, tailor etc)
        16 gold is paid to administrators
    - Build right taxes represent the King's tax to build the building, so it depends on how valuable the building's outputs are
    - 2 wood is a full-size tree cut into logs or shaped with an axe
    - tools represent any kind of mechanism (rope, pulley, or a true tool)

]]



-- Add to beginning inventory
mod:overrideAsset({
	Id = "DEFAULT_VILLAGE_CENTER_INVENTORY",
	Collection = {
        Action = "APPEND",
        {Resource = "BERRIES", Quantity = 30},
        {Resource = "TOOL", Quantity = 20},
        {Resource = "PLANK", Quantity = 20},
    }
})



-- Reduce territory taxes
mod:overrideAsset({
	Id = "DEFAULT_BALANCING",
	TerritoryRoyalTaxesList = {
		{ { Resource = "GOLD", Quantity = 0 } },
		{ { Resource = "GOLD", Quantity = 5 } },
		{ { Resource = "GOLD", Quantity = 10 } },
		{ { Resource = "GOLD", Quantity = 15 } },
		{ { Resource = "GOLD", Quantity = 20 } },
		{ { Resource = "GOLD", Quantity = 25 } },
		{ { Resource = "GOLD", Quantity = 30 } },
		{ { Resource = "GOLD", Quantity = 35 } },
		{ { Resource = "GOLD", Quantity = 40 } },
		{ { Resource = "GOLD", Quantity = 45 } },
		{ { Resource = "GOLD", Quantity = 50 } },
	}
})



-- Purchase prices for goods and services
mod:overrideAsset({ Id = "FAITH", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 1 } })
mod:overrideAsset({ Id = "BERRIES", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 1 } })
mod:overrideAsset({ Id = "BV1_EGG", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
mod:overrideAsset({ Id = "GRAPES", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
mod:overrideAsset({ Id = "MILK", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
mod:overrideAsset({ Id = "WOOD", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })

-- mod:overrideAsset({ Id = "RESOURCE_CANDLE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "CANDLE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "COAL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "FISH", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "HERBS", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "LEATHER", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
mod:overrideAsset({ Id = "RESOURCE_POULTRY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })

mod:overrideAsset({ Id = "RESOURCE_VEGETABLE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
mod:overrideAsset({ Id = "RESOURCE_FRUIT", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
mod:overrideAsset({ Id = "CHEESE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
mod:overrideAsset({ Id = "HONEY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
-- mod:overrideAsset({ Id = "PV3_PASTRY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
-- mod:overrideAsset({ Id = "PV4_PASTRY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
mod:overrideAsset({ Id = "BV1_PASTRY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
-- mod:overrideAsset({ Id = "MEAT_RESOURCE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 8 } })

mod:overrideAsset({ Id = "BREAD", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 8 } })
mod:overrideAsset({ Id = "BV1_MEAT", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 8 } })
mod:overrideAsset({ Id = "RESOURCE_CIDER", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 8 } })
mod:overrideAsset({ Id = "BEER", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 8 } })

mod:overrideAsset({ Id = "BOAR", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 12 } })
mod:overrideAsset({ Id = "CLOTHES", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 12 } })
mod:overrideAsset({ Id = "COMMON_WARES", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 12 } })
mod:overrideAsset({ Id = "WINE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 12 } })
mod:overrideAsset({ Id = "RESOURCE_FURNITURE", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 12 } })
mod:overrideAsset({ Id = "GEMS", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 100 } })
mod:overrideAsset({ Id = "JEWELRY", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 150 } })
mod:overrideAsset({ Id = "MEAL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 10 } }) -- game seems to double this price, so real price is 20

-- mod:overrideAsset({ Id = "RESOURCE_BERRIES_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 1 } })
-- mod:overrideAsset({ Id = "RESOURCE_WOOD_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
-- mod:overrideAsset({ Id = "RESOURCE_MILK_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
-- mod:overrideAsset({ Id = "RESOURCE_POULTRY_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 4 } })
-- mod:overrideAsset({ Id = "RESOURCE_EGG_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 2 } })
-- mod:overrideAsset({ Id = "RESOURCE_VEGETABLE_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
-- mod:overrideAsset({ Id = "RESOURCE_FRUIT_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })
-- mod:overrideAsset({ Id = "RESOURCE_HONEY_SELL", VillagerBuyingPrice = { Resource = "GOLD_COINS", Quantity = 6 } })



-- -- Tax Collectors: Double employment, add more taxable buildings -------------------------------------------------------------------------------------
-- mod:overrideAsset({
--     Id = "BUILDING_FUNCTION_TAX_OFFICE",
--     WorkerCapacity = 2,
--     -- TaxableBuildingList = { -- this causes an error
--     --     Action = "APPEND",
--     --     "BUILDING_BAKERY",
--     --     "BUILDING_BLACKSMITH",
--     --     "BUILDING_BREWERY",
--     --     "BUILDING_CHEESE_MAKER",
--     --     "BUILDING_COOPERAGE",
--     --     "BUILDING_JEWELER_WORKSHOP",
--     --     "BUILDING_STONEMASON_HUT",
--     --     "BUILDING_TAILOR_WORKSHOP",
--     --     "BUILDING_WEAPONSMITH",
--     --     "BUILDING_WEAVER_HUT",
--     --     "BUILDING_WINDMILL",
--     --     "MONUMENT_TAVERN",
--     --     "MONUMENT_MARKET"
--     -- }
-- })



-- -- Increase warehouse capacity -------------------------------------------------------------------------------------
-- mod:overrideAsset({
-- 	Id = "BUILDING_FUNCTION_WAREHOUSE",
-- 	SocketCapacity = 200,
-- 	WorkerCapacity = 4
-- })



-- -- Increase granary capacity -------------------------------------------------------------------------------------
-- mod:overrideAsset({
-- 	Id = "BUILDING_FUNCTION_GRANARY",
-- 	SocketCapacity = 200,
-- 	WorkerCapacity = 4
-- })



-- -- Slow down the shepherd -------------------------------------------------------------------------------------
-- mod:overrideAsset({
-- 	Id = "SHEPHERD",
-- 	ProductionDelay = 45
-- })



-- -- Slow down the fisherman -------------------------------------------------------------------------------------
-- mod:overrideAsset({
-- 	Id = "FISHERMAN",
-- 	ProductionDelay = 60
-- })



-- Slow down the forager -------------------------------------------------------------------------------------
mod:overrideAsset({
	Id = "GATHERER",
	ProductionDelay = 30
})



-- Slow down the woodcutter -------------------------------------------------------------------------------------
mod:overrideAsset({
	Id = "GATHERER",
	ProductionDelay = 30
})



-- Increase Beer production -------------------------------------------------------------------------------------
-- Didn't alter the production delay as there is a long animation involved
-- Instead I double production from every unit of hops
mod:overrideAsset({
    Id = "BUILDING_FUNCTION_BREWERY",
    ResourceProduced = {{ Resource = "BEER", Quantity = 2 }}
})



-- Implement all changes to main Balancing asset -------------------------------------------------------------------------------------
mod:overrideAsset({
    Id = "DEFAULT_BALANCING",
--    InitialFamilyCount = 14,  -- makes more people available at the beginning of the game
    VillagerCountPerImmigrationWave = {1, 3}, -- increases number of people possible in each wave to between 1 and 6
})



-- Lumber camp
mod:overrideAsset({
    Id = "BUILDING_PART_WOODCUTTER_CAMP",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 2 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 1 },
                { Resource = "TOOL", Quantity = 2 },
            },
        },
    }
})

-- Stonecutter camp
mod:overrideAsset({
    Id = "BUILDING_PART_STONECUTTER_CAMP",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 2 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 1 },
                { Resource = "TOOL", Quantity = 2 },
            },
        },
    }
})

-- Well
mod:overrideAsset({
    Id = "BUILDING_PART_WELL",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 2 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 1 },
                { Resource = "STONE", Quantity = 4 },
                { Resource = "TOOL", Quantity = 1 },
            },
        },
    }
})

-- Gathering hut
mod:overrideAsset({
    Id = "BUILDING_PART_GATHERING_CAMP",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 2 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 5 },
            },
        },
    }
})

-- Sawmill
mod:overrideAsset({
    Id = "BUILDING_PART_SAWMILL",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 12 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 20 },
                { Resource = "STONE", Quantity = 10 },
                { Resource = "TOOL", Quantity = 3 },
            },
        },
    }
})

-- Stonemason hut
mod:overrideAsset({
    Id = "BUILDING_PART_STONEMASON",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 1 },
                { Resource = "STONE", Quantity = 2 },
                { Resource = "WOOLEN_CLOTH", Quantity = 5 },
                { Resource = "TOOL", Quantity = 1 },
            },
        },
    }
})

-- Granary
mod:overrideAsset({
    Id = "BUILDING_PART_GRANARY",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 20 },
            },
        },
    }
})

-- Warehouse
mod:overrideAsset({
    Id = "BUILDING_PART_WAREHOUSE",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 20 },
            },
        }
    }
})

-- Foresters camp
mod:overrideAsset({
    Id = "BUILDING_PART_FORESTER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 1 },
            },
        }
    }
})

-- Dairy farm
mod:overrideAsset({
    Id = "BUILDING_PART_DAIRY_FARM",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 20 },
                { Resource = "STONE", Quantity = 10 },
                { Resource = "TOOL", Quantity = 5 },
            },
        }
    }
})

-- Blacksmith
mod:overrideAsset({
    Id = "BUILDING_PART_BLACKSMITH",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "TOOL", Quantity = 10 },
                { Resource = "STONE", Quantity = 20 },
                { Resource = "POLISHED_STONE", Quantity = 5 },
            },
        }
    }
})

-- Iron Smelter
mod:overrideAsset({
    Id = "BUILDING_PART_IRON_SMELTER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 10 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "TOOL", Quantity = 10 },
                { Resource = "STONE", Quantity = 20 },
            },
        }
    }
})

-- Coal hut
mod:overrideAsset({
    Id = "BUILDING_PART_COAL_HUT",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 5 },
                { Resource = "PLANK", Quantity = 10 },
                { Resource = "STONE", Quantity = 10 },
            },
        }
    }
})

-- Sheep farm
mod:overrideAsset({
    Id = "BUILDING_PART_SHEEP_FARM",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 15 },
                { Resource = "STONE", Quantity = 2 },
            },
        }
    }
})

-- Wheat farm
mod:overrideAsset({
    Id = "BUILDING_PART_WHEAT_FARM",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 15 },
                { Resource = "PLANK", Quantity = 5 },
                { Resource = "STONE", Quantity = 2 },
                { Resource = "TOOL", Quantity = 3 },
            },
        }
    }
})

-- Bakery
mod:overrideAsset({
    Id = "BUILDING_PART_BAKERY",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 10 }
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 10 },
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Windmill
mod:overrideAsset({
    Id = "BUILDING_PART_WINDMILL",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "STONE", Quantity = 15 },
                { Resource = "TOOL", Quantity = 10 },
            },
        }
    }
})

-- Weaver
mod:overrideAsset({
    Id = "BUILDING_PART_WEAVER_HUT",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "PLANK", Quantity = 15 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "STONE", Quantity = 10 },
                { Resource = "TOOL", Quantity = 5 },
            },
        }
    }
})

-- Tailor
mod:overrideAsset({
    Id = "BUILDING_PART_TAILOR_WORKSHOP",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "PLANK", Quantity = 15 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "STONE", Quantity = 10 },
                { Resource = "TOOL", Quantity = 5 },
            },
        }
    }
})

-- Fisher
mod:overrideAsset({
    Id = "BUILDING_PART_FISHING_HUT",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 10 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 },
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Hunter's Hut
mod:overrideAsset({
    Id = "BUILDING_PART_HUNTERS_HUT",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 1 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 6 },
                { Resource = "TOOL", Quantity = 1 }
            },
        }
    }
})

-- Cheese maker
mod:overrideAsset({
    Id = "BUILDING_PART_CHEESE_MAKER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 }
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 15 },
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Brewery
mod:overrideAsset({
    Id = "BUILDING_PART_BREWERY",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 }
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 15 },
                { Resource = "PLANK", Quantity = 20 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Hop farm
mod:overrideAsset({
    Id = "BUILDING_PART_HOP_FARM",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 15 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 10 }
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 15 },
                { Resource = "PLANK", Quantity = 10 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Cooperage
mod:overrideAsset({
    Id = "BUILDING_PART_COOPERAGE",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 },
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 8 },
                { Resource = "PLANK", Quantity = 10 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})

-- Vineyard
mod:overrideAsset({
    Id = "BUILDING_PART_VINEYARD",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 },
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 2 },
                { Resource = "PLANK", Quantity = 2 },
                { Resource = "WOOD", Quantity = 4 },
                { Resource = "TOOL", Quantity = 4 },
            },
        }
    }
})

-- Weaponsmith
mod:overrideAsset({
    Id = "BUILDING_PART_WEAPONSMITH",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 },
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 25 },
        },
        ResourceNeededList = {
            {
                { Resource = "STONE", Quantity = 8 },
                { Resource = "PLANK", Quantity = 10 },
                { Resource = "WOOD", Quantity = 10 },
                { Resource = "TOOL", Quantity = 5 },
            },
        }
    }
})

-- Gold Smelter
mod:overrideAsset({
    Id = "BUILDING_PART_GOLD_SMELTER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 30 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 25 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 8 },
                { Resource = "WOOD", Quantity = 4 },
                { Resource = "PLANK", Quantity = 2 },
                { Resource = "TOOL", Quantity = 5 },
            },
        }
    }
})

-- Glass Smelter
mod:overrideAsset({
    Id = "BUILDING_PART_GLASS_SMELTER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 25 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 15 }
        },
        ResourceNeededList = {
            {
                { Resource = "WOOD", Quantity = 4 },
                { Resource = "PLANK", Quantity = 4 },
                { Resource = "TOOL", Quantity = 2 },
                { Resource = "WOOLEN_CLOTH", Quantity = 2 },
            },
        },
    },
})


-- Candlemaker
mod:overrideAsset({
    Id = "BUILDING_PART_CANDLE_WORKSHOP_CORE",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 12 },
                { Resource = "WOOD", Quantity = 8 },
                { Resource = "PLANK", Quantity = 12 },
                { Resource = "TOOL", Quantity = 4 },
            },
        }
    }
})

mod:overrideAsset({
    Id = "BUILDING_PART_CANDLE_WORKSHOP_EXTENSION",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 4 },
                { Resource = "WOOD", Quantity = 2 },
                { Resource = "PLANK", Quantity = 6 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})


-- Common Wares
mod:overrideAsset({
    Id = "BUILDING_PART_COMMON_WARES_WORKSHOP_CORE",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 20 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 20 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 12 },
                { Resource = "WOOD", Quantity = 8 },
                { Resource = "PLANK", Quantity = 12 },
                { Resource = "TOOL", Quantity = 4 },
            },
        }
    }
})

mod:overrideAsset({
    Id = "BUILDING_PART_COMMON_WARES_WORKSHOP_TOWER",
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD", Quantity = 5 }
        },
        UpkeepCost = {
            { Resource = "GOLD", Quantity = 5 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 4 },
                { Resource = "WOOD", Quantity = 2 },
                { Resource = "PLANK", Quantity = 6 },
                { Resource = "TOOL", Quantity = 2 },
            },
        }
    }
})
